sample_test_fail_first_setup_20150203_185047

### sample_config1

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
3 | 3 | 0 | 0 | 2015-02-03 18:51:22 | 2015-02-03 18:51:22 | 0.252639055252 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test1 | Passed | Test has no docstring :(
test0 | Passed | Test has no docstring :(
test2 | Passed | Test has no docstring :(

###

Config Key | Value
--- | ---
TEST_OPTION | foo
BAR | baz
max_failures_per_suite_before_abort | -1